@@ -1,6 +1,7 @@
 """
 Google Play Store Scraper
 """
+import datetime
 import requests
 import json
 import re
@@ -38,14 +39,18 @@ class PlayStoreScraper:
 		url += "&hl=" + lang
 		url += "&gl=" + country
 
+		amount = int(num) * int(page)
+
 		try:
 			result = requests.get(url).text
 			data = self.extract_json_block(result, "ds:3")
 			data = json.loads(data)
 		except json.JSONDecodeError:
 			raise PlayStoreException("Could not parse search query response")
+		except IndexError:
+			return []
 
-		return [app[12][0] for app in data[0][1][0][0][0]][:(num * page)]
+		return [app[12][0] for app in data[0][1][0][0][0]][:amount]
 
 	def get_app_ids_for_collection(self, collection="", category="", age="", num=50, lang="nl", country="nl"):
 		"""
@@ -90,7 +95,7 @@ class PlayStoreScraper:
 			result = requests.get(url).text
 			block = self.extract_json_block(result, "ds:3")
 			data = json.loads(block)
-		except json.JSONDecodeError:
+		except (json.JSONDecodeError, PlayStoreException):
 			raise PlayStoreException("Could not parse Play Store response")
 
 		return [app[12][0] for app in data[0][1][0][0][0]]
@@ -107,8 +112,13 @@ class PlayStoreScraper:
 
 		:return list:  List of App IDs linked to developer
 		"""
-		url = self.PLAYSTORE_URL + "/store/apps/developer?id="
-		url += quote_plus(developer_id)
+		try:
+			developer_id = int(developer_id)
+			url = self.PLAYSTORE_URL + "/store/apps/dev?id="
+		except ValueError:
+			url = self.PLAYSTORE_URL + "/store/apps/dev?id="
+
+		url += quote_plus(str(developer_id))
 
 		url += "&hl=" + lang
 		url += "&gl=" + country
@@ -117,7 +127,7 @@ class PlayStoreScraper:
 			result = requests.get(url).text
 			data = self.extract_json_block(result, "ds:3")
 			data = json.loads(data)
-		except json.JSONDecodeError:
+		except (json.JSONDecodeError, PlayStoreException):
 			raise PlayStoreException("Could not parse Play Store response")
 
 		return [app[12][0] for app in data[0][1][0][0][0]][:num]
@@ -148,7 +158,7 @@ class PlayStoreScraper:
 			data = self.extract_json_block(result, "ds:7")
 			data = json.loads(data)
 			similar_url = self.PLAYSTORE_URL + data[1][1][0][0][3][4][2]
-		except json.JSONDecodeError:
+		except (json.JSONDecodeError, PlayStoreException):
 			raise PlayStoreException("Could not parse Play Store response")
 
 		try:
@@ -190,12 +200,16 @@ class PlayStoreScraper:
 
 		groups = []
 		for list in data:
+			if not list:
+				continue
 			for item in list:
 				groups.append(item)
 
 		result = []
 		for group in groups:
-			if not group[0]:
+			if not group:
+				continue
+			elif not group[0]:
 				result.append(group[1])
 			else:
 				for permission in group[2]:
@@ -217,6 +231,7 @@ class PlayStoreScraper:
 
 		:return dict:  App details, as returned by the Play Store.
 		"""
+		print(app_id)
 		url = self.PLAYSTORE_URL + "/store/apps/details?id="
 		url += quote_plus(app_id)
 
@@ -232,10 +247,10 @@ class PlayStoreScraper:
 			pegi = json.loads(self.extract_json_block(result, "ds:11"))
 			rating = json.loads(self.extract_json_block(result, "ds:14"))
 
-		except json.JSONDecodeError:
+		except (json.JSONDecodeError, PlayStoreException):
 			raise PlayStoreException("Could not parse Play Store response")
 
-		return {
+		app = {
 			"img_src": info[0][12][1][3][2],
 			"title": info[0][0][0],
 			"link": url,
@@ -243,12 +258,11 @@ class PlayStoreScraper:
 			"developer_link": self.PLAYSTORE_URL + info[0][12][5][5][4][2],
 			"developer_name": info[0][12][5][1],
 			"description": info[0][10][0][1],
-			"rating": rating[0][0][0][7][0][1] if rating[0][0][0][7] else 0,
 			"price_inapp": info[0][12][12][0] if info[0][12][12] else "",
 			"category": info[0][12][25],
 			"num_downloads": info[0][12][9][2],
 			"num_downloads_approx": info[0][12][9][1],
-			"published": info[0][12][8][0],
+			"published": datetime.datetime.fromtimestamp(int(info[0][12][8][0])).strftime("%c"),
 			"published_timestamp": info[0][12][8][0],
 			"pegi": pegi[0][1][2][9][0],
 			"filesize": version[0],
@@ -258,6 +272,13 @@ class PlayStoreScraper:
 				2] else 0
 		}
 
+		try:
+			app["rating"] = rating[0][0][0][7][0][1]
+		except TypeError:
+			app["rating"] = 0
+
+		return app
+
 	def get_multiple_app_details(self, app_ids, country="nl", lang="nl"):
 		"""
 		Get app details for a list of app IDs
@@ -290,8 +311,11 @@ class PlayStoreScraper:
 		prefix = re.compile(r"AF_init[dD]ata[cC]all[bB]ack\s*\({[^{}]*key:\s*'" + re.escape(block_id) + ".*?data:")
 		suffix = re.compile(r"}\s*\)\s*;")
 
-		block = prefix.split(html)[1]
-		block = suffix.split(block)[0]
+		try:
+			block = prefix.split(html)[1]
+			block = suffix.split(block)[0]
+		except IndexError:
+			raise PlayStoreException("Could not extract block %s" % block_id)
 
 		block = block.strip()
 		block = re.sub(r"^function\s*\([^)]*\)\s*{", "", block)
